@@ -85,12 +85,12 @@ the message begins with "[*+-] ".
 =item B<--sign-commit>, B<--no-sign-commit>
 
 If this option is set, then the commits that debcommit creates will be
-signed using gnupg. Currently this is only supported by git, hg, and bzr.
+OpenPGP signed. Currently this is only supported by git, hg, and bzr.
 
 =item B<--sign-tags>, B<--no-sign-tags>
 
-If this option is set, then tags that debcommit creates will be signed
-using gnupg. Currently this is only supported by git.
+If this option is set, then tags that debcommit creates will be OpenPGP
+signed. Currently this is only supported by git.
 
 =item B<--signoff>, B<--no-signoff>
 
